/**
 * Copyright (c) 2011-2012 INRIA.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>
 **/
package org.bitbucket.lp.maven.plugins.svuid;

import java.io.File;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.apache.maven.plugin.logging.Log;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.apache.maven.plugins.annotations.ResolutionScope;
import org.bitbucket.lp.maven.plugins.svuid.transformers.IncrementTransformer;

/**
 * Increments by default the value of all the declared serialVersionUID fields
 * by one. It is possible to use the by argument to specify the increment value.
 * Moreover, the operation may be performed only on the fields whose the value
 * is equals to a given value by using the if parameter.
 * 
 * @author lpellegr
 */
@Mojo(name = "increment", defaultPhase = LifecyclePhase.NONE, requiresOnline = false, requiresDependencyResolution = ResolutionScope.NONE, requiresDirectInvocation = true, threadSafe = false)
public class IncrementMojo extends SvuidMojo {

    @Parameter(property = "increment", readonly = true, required = false)
    private Integer increment = Integer.valueOf(1);

    @Parameter(property = "if", readonly = true, required = false)
    private Long equalsValue = Long.valueOf(-1);

    /**
     * {@inheritDoc}
     */
    @Override
    public void execute() throws MojoExecutionException, MojoFailureException {
        Map<File, List<SerialVersionUidEntry>> entries =
                findFilesDeclaringSerialVersionUID(super.srcFolder);

        Log log = super.getLog();

        if (entries.isEmpty()) {
            log.info(NO_FILE_FOUND_MSG);
            return;
        }

        for (Entry<File, List<SerialVersionUidEntry>> entry : entries.entrySet()) {
            File file = entry.getKey();

            replaceSerialVersionUidFields(file, new IncrementTransformer(
                    this.increment, this.equalsValue));
        }
    }

}
