/**
 * Copyright (c) 2011-2012 INRIA.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>
 **/
package org.bitbucket.lp.maven.plugins.svuid.transformers;

/**
 * A simple transformer used to increment serialVersionUID fields by one or the
 * specified increment value. It is also possible to apply the transformation
 * only under the condition that the old value is equals to a given value.
 * 
 * @author lpellegr
 */
public class IncrementTransformer extends Transformer {

    private final int increment;

    private final long equalsValue;

    public IncrementTransformer() {
        this(1, -1);
    }

    public IncrementTransformer(int increment, long equalsValue) {
        this.increment = increment;
        this.equalsValue = equalsValue;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public long apply(long oldSerialVersionUidValue) {
        if (this.equalsValue == -1) {
            return oldSerialVersionUidValue + this.increment;
        } else {
            if (oldSerialVersionUidValue == this.equalsValue) {
                return oldSerialVersionUidValue + this.increment;
            } else {
                return -1;
            }
        }
    }

}
