/**
 * Copyright (c) 2011-2012 INRIA.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>
 **/
package org.bitbucket.lp.maven.plugins.svuid.transformers;

/**
 * A simple transformer used to set serialVersionUID fields to a given value.
 * This transformer can also be applied only under the condition that the old
 * value is equals to a given value.
 * 
 * @author lpellegr
 */
public class SetTransformer extends Transformer {

    private final long newSerialVersionUidValue;

    private final long equalsValue;

    public SetTransformer(long newSerialVersionUidValue) {
        this(newSerialVersionUidValue, -1);
    }

    public SetTransformer(long newSerialVersionUidValue, long equalsValue) {
        this.newSerialVersionUidValue = newSerialVersionUidValue;
        this.equalsValue = equalsValue;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public long apply(long oldSerialVersionUidValue) {
        if (this.equalsValue == -1) {
            return this.newSerialVersionUidValue;
        } else {
            if (oldSerialVersionUidValue == this.equalsValue) {
                return this.newSerialVersionUidValue;
            } else {
                return -1;
            }
        }
    }

}
